<template>
  <ProTableQueryFilterBar @on-reset="reset">
    <template #query>
      <QueryFilterItem>
        <SearchInput
          v-model="extraParamState.searchKeyWord"
          style="width: 250px"
          placeholder="企业名/信用代码"
          @on-click-search="getList"
        >
        </SearchInput>
      </QueryFilterItem>
    </template>
  </ProTableQueryFilterBar>
  <ProTableV2
    v-bind="proTableProps"
    :columns="column"
    :operationBtns="operationBtns"
    :autoHeight="false"
    :tableProps="{
      maxHeight: '400px',
    }"
  >
  </ProTableV2>
  <MateriaDetailDialog v-bind="dialogProps"></MateriaDetailDialog>
</template>

<script setup lang="ts">
import {
  ProTableQueryFilterBar,
  QueryFilterItem,
  ProTableV2,
  SearchInput,
  useFormDialog,
  defineOperationBtns,
  defineColumns,
} from '@bole-core/components';
import MateriaDetailDialog from './MateriaDetailDialog.vue';
import { FourStreamsMaterialFileTableItem } from './types';

defineOptions({
  name: 'DeclareEnterpriseTableView',
});

type Props = {
  getList: (pageIndex?: number) => Promise<void>;
  reset: () => void;
  proTableProps: any;
  extraParamState: {
    searchKeyWord: string;
  };
};

const props = withDefaults(defineProps<Props>(), {});

const column = defineColumns([
  {
    id: '1',
    enCode: 'userName',
    name: '帐号',
  },
  {
    id: '2',
    enCode: 'enterpriseName',
    name: '企业名称',
  },
  {
    id: '3',
    enCode: 'societyCreditCode',
    name: '信用代码',
  },
  {
    id: '4',
    enCode: 'contactPhone',
    name: '电话',
  },
  {
    id: '5',
    enCode: 'authType',
    name: '企业类型',
  },
  {
    id: '6',
    enCode: 'licenseUrl',
    name: '营业执照',
  },
  {
    id: '7',
    enCode: 'bankAccountInfo',
    name: '基本户信息',
  },
]);

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '详情',
    },
    emits: {
      onClick: (role) => openDialog(role),
    },
  },
]);

const { dialogProps, handleEdit, editForm } = useFormDialog({
  defaultFormParams: {
    list: [] as FourStreamsMaterialFileTableItem[],
  },
});

function openDialog(row?: API.ParkBountyApplyDetailInfo) {
  handleEdit({
    list: [],
  });
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
